package com.sf.sms.driver.job;

package ..deTemp.1733581807379;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.core.util.XmlUtil;
import java.io.File;
import java.util.ArrayList;
import java.util.List;
import javax.annotation.PostConstruct;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springblade.msg.sms.bo.req.SmsSendReq;
import org.springblade.msg.sms.bo.resp.SmsSendResp;
import org.springblade.msg.sms.service.ISmsSender;
import org.springframework.core.env.Environment;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

@Component
public class SmsJob {
  public SmsJob(ISmsSender smsSender, Environment environment) {
    this.smsSender = smsSender;
    this.environment = environment;
  }
  
  private static final Logger log = LoggerFactory.getLogger(com.sf.sms.driver.job.SmsJob.class);
  
  private final ISmsSender smsSender;
  
  private final Environment environment;
  
  private static Integer msgMaxNum;
  
  private static String path;
  
  @PostConstruct
  public void init() {
    msgMaxNum = (Integer)this.environment.getProperty("msg.max-num", Integer.class);
    path = (String)this.environment.getProperty("watch.path", String.class);
  }
  
  @Scheduled(cron = "0/2 * * * * ?")
  public void task() {
    File dirPath = new File(path);
    if (!dirPath.exists() || !dirPath.isDirectory())
      return; 
    for (File file : dirPath.listFiles()) {
      if (file.isFile() && file.getName().endsWith(".xml")) {
        SmsSendReq sendReq = buildSmsSendReq(file);
        file.delete();
        if (sendReq != null && 
          msgMaxNum != null && msgMaxNum.intValue() > 0) {
          List<String> recvList = sendReq.getRecvList();
          List<List<String>> subRecvList = CollectionUtil.split(recvList, msgMaxNum.intValue());
          for (List<String> subRecv : subRecvList) {
            sendReq.setRecvList(subRecv);
            try {
              SmsSendResp resp = this.smsSender.doSend(sendReq);
              if (!resp.isSuccess())
                log.error("短信发送失败,发送内容:{},发送列表:{},失败原因:{}", new Object[] { sendReq.getContent(), sendReq.getRecvList(), resp.getMessage() }); 
            } catch (Exception e) {
              log.error("短信发送失败,发送内容:{},发送列表:{},失败原因:{}", new Object[] { sendReq.getContent(), sendReq.getRecvList(), e.getMessage() });
            } 
          } 
        } 
      } 
    } 
  }
  
  private SmsSendReq buildSmsSendReq(File file) {
    Document document = XmlUtil.readXML(file);
    if (document == null)
      return null; 
    Element root = XmlUtil.getRootElement(document);
    if (root == null)
      return null; 
    String content = root.getAttribute("name");
    if (StrUtil.isBlank(content))
      return null; 
    List<String> phoneList = new ArrayList<>();
    Element iPhonesElement = XmlUtil.getElement(root, "iphones");
    List<Element> iPhoneElementList = XmlUtil.getElements(iPhonesElement, "iphone");
    for (Element iPhoneElement : iPhoneElementList)
      phoneList.add(iPhoneElement.getAttribute("name")); 
    return SmsSendReq.builder().content(content).recvList(phoneList).build();
  }
}
